==> typescript-dev-kit-0.0.18.tgz: package/config/webpack.config.dev.js <==
/**
 * Copyright 2016 - present, Matthieu Jabbour <matthieu.jabbour@gmail.com>.
 * All rights reserved.
 */


/* eslint-disable no-console, import/no-unresolved */


const path = require('path');
const webpack = require('webpack');
const userConfig = require('../../../config.ts');
const validateConfig = require('./validateConfig');
const packageJson = require('../../../package.json');
const ClearTerminalPlugin = require('./ClearTerminalPlugin');


try {
  validateConfig(userConfig);
} catch (error) {
  console.error(error);
  process.exit();
}


// Contains all webpack's context-agnostic development configuration
// (which is common to both front-end and back-end projects types).
const baseConfig = {
  target: userConfig.target,
  bail: false,
  cache: true,
  mode: 'development',
  context: userConfig.srcPath,
  devtool: 'cheap-module-source-map',
  resolve: {
    extensions: ['.json', '.ts', '.tsx', '.js', '*'],
  },
  module: {
    rules: [
      {
        test: /\.tsx?$/,
        include: [userConfig.srcPath],
        use: [
          // `awesome-typescript-loader` is then used, to compile Typescript into Javascript.
          {
            loader: 'awesome-typescript-loader',
            options: {
              useCache: true,
            },
          },
          // `tslint-loader` is first used, to lint the code.
          {
            loader: 'tslint-loader',
            options: {
              emitErrors: true,
              failOnHint: true,
              typeCheck: true,
            },
          },
        ],
      },
      // Stylesheets.
      {
        test: /\.css$/,
        use: [
          // `css-loader` resolves paths in CSS and adds assets as dependencies.
          {
            loader: 'css-loader',
            options: { sourceMap: true, import: false },
          },
          // `postcss-loader` is used to autoprefix CSS to ensure compatibility with all browsers.
          {
            loader: 'postcss-loader',
            options: {
              config: { path: path.resolve(__dirname, 'postcss.config.js') },
              sourceMap: true,
            },
          },
        ],
      },
      // Audio and video files.
      {
        test: /\.(mp4|webm|ogg|mp3|wav|flac|aac)(\?.*)?$/,
        loader: 'url-loader',
        options: {
          limit: 10 * 1024,
          name: 'media/[name].[ext]',
        },
      },
      // Images files.
      {
        test: /\.(png|jpe?g|gif|svg)(\?.*)?$/,
        loader: 'url-loader',
        options: {
          limit: 10 * 1024,
          name: 'images/[name].[ext]',
        },
      },
      // Fonts files.
      {
        test: /\.(woff2?|eot|ttf|otf)(\?.*)?$/,
        loader: 'url-loader',
        options: {
          limit: 10 * 1024,
          name: 'fonts/[name].[ext]',
        },
      },
    ],
  },
  plugins: [
    // Clears terminal between each compilation.
    new ClearTerminalPlugin(),
    // Includes copyright comment on top of each generated file.
    new webpack.BannerPlugin({
      banner: userConfig.banner,
      raw: true,
    }),
  ],
};


// Additional configuration for front-end projects.
if (userConfig.target === 'web') {
  baseConfig.entry = Object.keys(userConfig.entry).reduce((entries, entry) => {
    // eslint-disable-next-line no-param-reassign
    entries[entry] = [
      userConfig.entry[entry],
      // This entry is required to correctly enable HMR.
      'webpack-hot-middleware/client?dynamicPublicPath=true&timeout=4000&reload=true&path=_hmr',
    ];
    return entries;
  }, {});
  baseConfig.output = {
    path: `${userConfig.distPath}/assets`,
    filename: 'scripts/[name].js',
    publicPath: '/assets/',
    pathinfo: true,
  };
  baseConfig.plugins = baseConfig.plugins.concat([
    // Enables HMR with webpack-dev-middleware.
    new webpack.HotModuleReplacementPlugin(),
  ]);
  baseConfig.node = {
    // Prevents webpack from injecting useless setImmediate polyfill because Vue
    // source contains it (although only uses it if it's native).
    setImmediate: false,
    // Prevents webpack from injecting mocks to Node native modules
    // that does not make sense for the client.
    dgram: 'empty',
    fs: 'empty',
    net: 'empty',
    tls: 'empty',
    child_process: 'empty',
  };
  baseConfig.devServer = userConfig.devServer;
  baseConfig.optimization = {
    splitChunks: {
      chunks: 'all',
    },
    runtimeChunk: true,
  };


// Additional configuration for back-end projects.
} else {
  baseConfig.entry = userConfig.entry;
  baseConfig.externals = Object.keys(packageJson.dependencies).reduce(
    (externals, dependency) => Object.assign(externals, { [dependency]: dependency }),
    {},
  );
  baseConfig.output = {
    path: userConfig.distPath,
    filename: '[name].js',
    pathinfo: true,
    library: packageJson.name,
    libraryTarget: 'commonjs2',
  };
  // Disables all the nodeJS polyfills and mocks only if target is `node`.
  baseConfig.node = {
    console: false,
    global: false,
    process: false,
    __filename: false,
    __dirname: false,
    Buffer: false,
    setImmediate: false,
  };
}


module.exports = baseConfig;

==> typescript-dev-kit-0.0.19.tgz: package/config/webpack.config.dev.js <==
/**
 * Copyright 2016 - present, Matthieu Jabbour <matthieu.jabbour@gmail.com>.
 * All rights reserved.
 */


/* eslint-disable no-console, import/no-unresolved */


const path = require('path');
const webpack = require('webpack');
const userConfig = require('../../../config.ts');
const validateConfig = require('./validateConfig');
const packageJson = require('../../../package.json');
const ClearTerminalPlugin = require('./ClearTerminalPlugin');


try {
  validateConfig(userConfig);
} catch (error) {
  console.error(error);
  process.exit();
}


// Contains all webpack's context-agnostic development configuration
// (which is common to both front-end and back-end projects types).
const baseConfig = {
  target: userConfig.target,
  bail: false,
  cache: true,
  mode: 'development',
  context: userConfig.srcPath,
  devtool: 'cheap-module-source-map',
  resolve: {
    extensions: ['.json', '.ts', '.tsx', '.js', '*'],
  },
  module: {
    rules: [
      {
        test: /\.tsx?$/,
        include: [userConfig.srcPath],
        use: [
          // `awesome-typescript-loader` is then used, to compile Typescript into Javascript.
          {
            loader: 'awesome-typescript-loader',
            options: {
              useCache: true,
            },
          },
          // `tslint-loader` is first used, to lint the code.
          {
            loader: 'tslint-loader',
            options: {
              emitErrors: true,
              failOnHint: true,
              typeCheck: true,
            },
          },
        ],
      },
      // Stylesheets.
      {
        test: /\.css$/,
        use: [
          // `style-loader` turns CSS into JS modules that inject <style> tags.
          {
            loader: 'style-loader',
          },
          // `css-loader` resolves paths in CSS and adds assets as dependencies.
          {
            loader: 'css-loader',
            options: { sourceMap: true },
          },
          // `postcss-loader` is used to autoprefix CSS to ensure compatibility with all browsers.
          {
            loader: 'postcss-loader',
            options: {
              config: { path: path.resolve(__dirname, 'postcss.config.js') },
              sourceMap: true,
            },
          },
        ],
      },
      // Audio and video files.
      {
        test: /\.(mp4|webm|ogg|mp3|wav|flac|aac)(\?.*)?$/,
        loader: 'url-loader',
        options: {
          limit: 10 * 1024,
          name: 'media/[name].[ext]',
        },
      },
      // Images files.
      {
        test: /\.(png|jpe?g|gif|svg)(\?.*)?$/,
        loader: 'url-loader',
        options: {
          limit: 10 * 1024,
          name: 'images/[name].[ext]',
        },
      },
      // Fonts files.
      {
        test: /\.(woff2?|eot|ttf|otf)(\?.*)?$/,
        loader: 'url-loader',
        options: {
          limit: 10 * 1024,
          name: 'fonts/[name].[ext]',
        },
      },
    ],
  },
  plugins: [
    // Clears terminal between each compilation.
    new ClearTerminalPlugin(),
    // Includes copyright comment on top of each generated file.
    new webpack.BannerPlugin({
      banner: userConfig.banner,
      raw: true,
    }),
  ],
};


// Additional configuration for front-end projects.
if (userConfig.target === 'web') {
  baseConfig.entry = Object.keys(userConfig.entry).reduce((entries, entry) => {
    // eslint-disable-next-line no-param-reassign
    entries[entry] = [
      userConfig.entry[entry],
      // This entry is required to correctly enable HMR.
      'webpack-hot-middleware/client?dynamicPublicPath=true&timeout=4000&reload=true&path=_hmr',
    ];
    return entries;
  }, {});
  baseConfig.output = {
    path: `${userConfig.distPath}/assets`,
    filename: 'scripts/[name].js',
    publicPath: '/assets/',
    pathinfo: true,
  };
  baseConfig.plugins = baseConfig.plugins.concat([
    // Enables HMR with webpack-dev-middleware.
    new webpack.HotModuleReplacementPlugin(),
  ]);
  baseConfig.node = {
    // Prevents webpack from injecting useless setImmediate polyfill because Vue
    // source contains it (although only uses it if it's native).
    setImmediate: false,
    // Prevents webpack from injecting mocks to Node native modules
    // that does not make sense for the client.
    dgram: 'empty',
    fs: 'empty',
    net: 'empty',
    tls: 'empty',
    child_process: 'empty',
  };
  baseConfig.devServer = userConfig.devServer;
  baseConfig.optimization = {
    splitChunks: {
      chunks: 'all',
    },
    runtimeChunk: true,
  };


// Additional configuration for back-end projects.
} else {
  baseConfig.entry = userConfig.entry;
  baseConfig.externals = Object.keys(packageJson.dependencies).reduce(
    (externals, dependency) => Object.assign(externals, { [dependency]: dependency }),
    {},
  );
  baseConfig.output = {
    path: userConfig.distPath,
    filename: '[name].js',
    pathinfo: true,
    library: packageJson.name,
    libraryTarget: 'commonjs2',
  };
  // Disables all the nodeJS polyfills and mocks only if target is `node`.
  baseConfig.node = {
    console: false,
    global: false,
    process: false,
    __filename: false,
    __dirname: false,
    Buffer: false,
    setImmediate: false,
  };
}


module.exports = baseConfig;
